#!/bin/bash

EXEC=dropline-installer
TARGET=template.po
TARGET_NEW="$TARGET"".NEW"

bash --dump-po-strings $EXEC > $TARGET

cat /dev/null > $TARGET_NEW

line2="foo"
while [ -n "$line2" ]
do
	read line1
	read line2
	read line3
	
	if [ "$line2" != "" ]; then
		found=`grep -c -e "$line2" $TARGET_NEW`
	
		if [ "$found" == "0" ]; then
#			echo -E $line1; # >> $TARGET_NEW
			echo -E $line2; # >> $TARGET_NEW
#			echo -E $line3; # >> $TARGET_NEW
		fi
		
	fi
done < $TARGET

mv $TARGET_NEW $TARGET
